summaryrefslogtreecommitdiff
path: root/test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py')
-rw-r--r--test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py19
1 files changed, 9 insertions, 10 deletions
diff --git a/test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py b/test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py
index 22443615eb..eace9b26d3 100644
--- a/test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py
+++ b/test/lib/ansible_test/_internal/coverage/analyze/targets/missing.py
@@ -21,10 +21,9 @@ from . import (
if t.TYPE_CHECKING:
from . import (
TargetIndexes,
+ IndexedPoints,
)
- TargetKey = t.TypeVar('TargetKey', int, t.Tuple[int, int])
-
def command_coverage_analyze_targets_missing(args): # type: (CoverageAnalyzeTargetsMissingConfig) -> None
"""Identify aggregated coverage in one file missing from another."""
@@ -44,12 +43,12 @@ def command_coverage_analyze_targets_missing(args): # type: (CoverageAnalyzeTar
def find_gaps(
- from_data, # type: t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
+ from_data, # type: IndexedPoints
from_index, # type: t.List[str]
- to_data, # type: t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
- target_indexes, # type: TargetIndexes,
+ to_data, # type: IndexedPoints
+ target_indexes, # type: TargetIndexes
only_exists, # type: bool
-): # type: (...) -> t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
+): # type: (...) -> IndexedPoints
"""Find gaps in coverage between the from and to data sets."""
target_data = {}
@@ -69,13 +68,13 @@ def find_gaps(
def find_missing(
- from_data, # type: t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
+ from_data, # type: IndexedPoints
from_index, # type: t.List[str]
- to_data, # type: t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
+ to_data, # type: IndexedPoints
to_index, # type: t.List[str]
- target_indexes, # type: TargetIndexes,
+ target_indexes, # type: TargetIndexes
only_exists, # type: bool
-): # type: (...) -> t.Dict[str, t.Dict[TargetKey, t.Set[int]]]
+): # type: (...) -> IndexedPoints
"""Find coverage in from_data not present in to_data (arcs or lines)."""
target_data = {}